antimarkdown
============

Convert HTML to Markdown, quickly and easily:

::

    >>> import antimarkdown
    >>> print(antimarkdown.to_markdown("""
    ... <h1>antimarkdown</h1>
    ...
    ... <p>Convert HTML to Markdown, quickly and easily!</p>
    ... """))
    antimarkdown
    ============

    Convert HTML to Markdown, quickly and easily!

